@@ -1,6 +1,6 @@
 ;;; ebib-filters.el --- Part of Ebib, a BibTeX database manager  -*- lexical-binding: nil -*-
 
-;; Copyright (c) 2003-2023 Joost Kremers
+;; Copyright (c) 2003-2024 Joost Kremers
 ;; All rights reserved.
 
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
@@ -261,28 +261,25 @@ See `ebib--filters-run-filter'.")
 
 (defun ebib--filters-pp-filter (filter)
   "Convert FILTER into a string suitable for displaying.
-If `ebib--filters-display-as-lisp' is set, this simply converts
+If `ebib-filters-display-as-lisp' is set, this simply converts
 FILTER into a string representation of the Lisp expression.
 Otherwise, it is converted into infix notation.  If FILTER is nil,
 return value is also nil."
   (when filter
     (if ebib-filters-display-as-lisp
         (format "%S" filter)
-      (cl-labels
-          ((pp-filter (f)
-                      (cond
-                       ((listp f) ; `f' is either a list or a string.
-                        (let ((op (cl-first f)))
-                          (cond
-                           ((eq op 'not)
-                            (format "not %s" (pp-filter (cl-second f))))
-                           ((eq op 'contains)
-                            (format "(%s contains \"%s\")" (pp-filter (cl-second f)) (pp-filter (cl-third f))))
-                           ((member op '(and or))
-                            (format "(%s %s %s)" (pp-filter (cl-second f)) op (pp-filter (cl-third f)))))))
-                       (t (if (string= f "any")
-                              "any field"
-                            f)))))
+      (cl-labels ((pp-filter (f)
+                    (cond
+                     ((listp f)                ; `f' is either a list or a string.
+                      (pcase (cl-first f)
+                        ('not
+                         (format "not %s" (pp-filter (cl-second f))))
+                        ('contains
+                         (format "(%s contains \"%s\")" (pp-filter (cl-second f)) (pp-filter (cl-third f))))
+                        (`,(or 'and 'or)
+                         (format "(%s %s %s)" (pp-filter (cl-second f)) (cl-first f) (pp-filter (cl-third f))))))
+                     ((string= f "any") "any field")
+                     (t f))))
         (let ((pretty-filter (pp-filter filter)))
           (if (not pretty-filter)
               "Filtered"
@@ -318,7 +315,7 @@ there is a name conflict."
         (let ((print-length nil)
               (print-level nil)
               (print-circle nil))
-          (insert ";; -*- mode: emacs-lisp -*-\n\n")
+          (insert ";; -*- mode: lisp-data -*-\n\n")
           (insert (format ";; Ebib filters file\n;; Saved on %s\n\n" (format-time-string "%Y.%m.%d %H:%M")))
           (pp ebib--filters-alist (current-buffer))
           (write-region (point-min) (point-max) file)))
